@@ -24,6 +24,16 @@
 #include "dialog.h"
 #include "slot.h"
 
+static guint32
+get_current_time (void)
+{
+	GTimeVal tval;
+
+	g_get_current_time (&tval);
+
+	return tval.tv_sec;
+}
+
 int waiting_for_mouse_up(void) {
   if (!press_data) return 0;
   if (press_data->status == STATUS_IS_DRAG) return 1;
@@ -84,7 +94,7 @@ void drop_moving_cards(gint x, gint y) {
   update_slot_length(hslot);
   press_data->cards = NULL;
 
-  gdk_window_get_size(press_data->moving_cards, &width, &height);
+  gdk_drawable_get_size(press_data->moving_cards, &width, &height);
   gdk_window_move(press_data->moving_cards, 
 		  hslot->x + hslot->width - width, 
 		  hslot->y + hslot->height - height);
@@ -94,9 +104,9 @@ void drop_moving_cards(gint x, gint y) {
   gdk_window_hide(press_data->moving_cards);
 
   if (press_data->moving_pixmap)
-    gdk_pixmap_unref(press_data->moving_pixmap);
+    gdk_drawable_unref(press_data->moving_pixmap);
   if (press_data->moving_mask)
-    gdk_pixmap_unref(press_data->moving_mask);
+    gdk_drawable_unref(press_data->moving_mask);
   press_data->moving_pixmap = NULL;
   press_data->moving_mask = NULL;
 
@@ -130,13 +140,12 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
   if (event->type != GDK_BUTTON_PRESS)
     return TRUE;
   
-  if ((event->button == 2) || 
-      (event->button == 3 && (press_data->status == STATUS_IS_DRAG)) ||
+  if ((event->button == 3 && (press_data->status == STATUS_IS_DRAG)) ||
       (event->button == 1 && (press_data->status == STATUS_SHOW || press_data->status == STATUS_IS_DRAG)))
     return TRUE;
 
 #ifndef SINGLE_ACTION
-  if (gdk_time_get() > first_press + dbl_click_time)
+  if (get_current_time() > first_press + dbl_click_time)
     press_data->status = STATUS_NONE;
 #endif
   slot_pressed(event->x, event->y, &hslot, &cardid);
@@ -166,7 +175,7 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
       return TRUE;
     }
     else {
-      first_press = gdk_time_get();
+      first_press = get_current_time();
       press_data->status = cardid > 0 ? STATUS_MAYBE_DRAG : STATUS_NOT_DRAG;
 #ifdef SINGLE_ACTION
       timer_click = 
@@ -194,15 +203,24 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
       gdk_window_move(press_data->moving_cards, x, y); 
       gdk_window_show(press_data->moving_cards);
     }
+  } 
+    else if (event->button == 2) {
+      gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
+		SCM_EOL);
+      if (gh_scm2bool (gh_call1 (game_data->button_double_clicked_lambda,
+		       gh_long2scm (hslot->id))))
+	      gh_call0 (gh_eval_str ("end-move"));
+      else
+	      gh_call0 (gh_eval_str ("discard-move"));
+      refresh_screen ();
+      end_of_game_test ();
+      return TRUE;
   }
   return TRUE;
 }
 
 gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 {
-  if (event->button == 2)
-    return TRUE;
-
   switch (press_data->status) {
   case STATUS_IS_DRAG:
     if (event->button != 1) return TRUE;
@@ -276,18 +294,17 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
     else
       press_data->status = STATUS_NOT_DRAG;      
   }
-  return TRUE;
+  return FALSE;
 }
 
 gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
-
   if(surface) {
     gint old_w, old_h;
 
-    gdk_window_get_size(surface, &old_w, &old_h);
+    gdk_drawable_get_size(surface, &old_w, &old_h);
     if(old_w == event->width && old_h == event->height)
       return TRUE;
-    gdk_pixmap_unref(surface);
+    gdk_drawable_unref(surface);
   }
   else {
     timer_start();
@@ -295,10 +312,10 @@ gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
 
   surface =
     gdk_pixmap_new (playing_area->window, event->width, event->height,
-		    gdk_window_get_visual (playing_area->window)->depth);
+		    gdk_drawable_get_visual (playing_area->window)->depth);
   
   refresh_screen();
 
-  return TRUE;
+  return FALSE;
 }
 
