@@ -124,7 +124,7 @@ GnomeUIInfo game_menu[] = {
 	
 	GNOMEUIINFO_SEPARATOR,
 
-        GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(quit_game_cb, NULL),
 
 	GNOMEUIINFO_END
 };
