@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <2000/05/09 18:20:21 martin>
+ * Time-stamp: <2002/05/02 17:09:45 dave>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -18,7 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <stdlib.h>
@@ -32,6 +36,7 @@
 #include "preferences.h"
 #include "io.h"
 #include "view.h"
+#include "sound.h"
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
@@ -111,13 +116,15 @@ static void
 game_start_cb (GtkWidget *widget, gpointer data);
 
 
+
 
 /****************************************************************************/
 /* Image stuff  */
 
 static void
 my_exit (GtkWidget *widget, gpointer client_data)
-{
+{ 
+  sound_close(); 
   exit (1);
 }
 
@@ -127,9 +134,10 @@ load_image_from_path (const char *relative_name)
   gchar         *filename;
   GdkPixbuf *image= NULL;
 
-  filename= gnome_pixmap_file (relative_name);
+  filename= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+                                       relative_name, TRUE, NULL);
   if (filename)
-    image= gdk_pixbuf_new_from_file (filename);
+    image= gdk_pixbuf_new_from_file (filename, NULL);
 
   g_free (filename);
   
@@ -142,11 +150,14 @@ load_image_from_path (const char *relative_name)
 		    "Please make sure, that Gnome-Stones is "
 		    "correctly installed!"), relative_name);
 					    
-      widget= gnome_error_dialog (buffer);
-      gtk_signal_connect (GTK_OBJECT (widget), "close",
-			  GTK_SIGNAL_FUNC (my_exit), NULL);
+      widget= gtk_message_dialog_new (GTK_WINDOW(app), 
+                                      GTK_DIALOG_DESTROY_WITH_PARENT,
+                                      GTK_MESSAGE_ERROR, 
+                                      GTK_BUTTONS_CLOSE, 
+                                      buffer);
+      gtk_dialog_run(GTK_DIALOG(widget));
 
-      gtk_main ();
+      gtk_widget_destroy(widget);
     }
   
   return image;
@@ -159,13 +170,16 @@ title_image_load (void)
 {
   GdkPixbuf *image= load_image_from_path ("gnome-stones/title.png");
 
-  gdk_pixbuf_render_pixmap_and_mask (image, &title_template, NULL, 127);
 
-  title_image = title_template; /* FIXME */
-  gdk_pixmap_ref (title_template);
+  gdk_pixbuf_render_pixmap_and_mask (image, &title_template, NULL, 127);
+  gdk_pixbuf_render_pixmap_and_mask (image, &title_image, NULL, 127);
+
+  gdk_pixbuf_unref (image);
 
   /* Redraw the game widget.  */
   gtk_widget_draw (gstones_view, NULL);
+  
+  
 }
 
 
@@ -234,55 +248,63 @@ static void
 game_update_title (void)
 {
   /* Replace image with template.  */
-  gdk_draw_pixmap (title_image,
-		   gstones_view->style->black_gc, title_template,
-		   0, 0,
-		   0, 0, GAME_COLS*STONE_SIZE, GAME_ROWS*STONE_SIZE);
+  gdk_draw_drawable (title_image,
+                     gstones_view->style->black_gc, title_template,
+                     0, 0,
+                     0, 0, GAME_COLS*STONE_SIZE, GAME_ROWS*STONE_SIZE);
 
   if (game)
     {
       static char *gametitle= N_("Game title:");
       static char *cavename = N_("Start cave:");
 
-      guint    height;
-      GdkFont *font;
+      guint    width, height;
+      PangoLayout *layout;
+      PangoFontDescription *pfd;
       GList   *tmp= g_list_nth (game->start_caves, start_cave);
 
-      font = gdk_font_ref (gstones_view->style->font);
-      if (!font)
-	font= gdk_font_load ("fixed");
-
-      height= font->ascent+font->descent;
-
-      gdk_draw_text   (title_image,
-		       font,
-		       gstones_view->style->black_gc,
-		       30, GAME_ROWS*STONE_SIZE-30-height*3-height/2,
-		       _(gametitle),
-		       strlen (_(gametitle)));
-
-      gdk_draw_text   (title_image,
-		       font,
-		       gstones_view->style->black_gc,
-		       30, GAME_ROWS*STONE_SIZE-30-height*2-height/2,
-		       game->title,
-		       strlen (_(game->title)));
+      layout = gtk_widget_create_pango_layout(gstones_view, _(gametitle));
+      pfd = pango_font_description_from_string("fixed");
+      pango_layout_set_font_description( layout, pfd);
       
-      gdk_draw_text   (title_image,
-		       font,
-		       gstones_view->style->black_gc,
-		       30, GAME_ROWS*STONE_SIZE-30-height,
-		       _(cavename),
-		       strlen (_(cavename)));
+      pango_layout_get_pixel_size (layout, &width, &height);
 
-      gdk_draw_text   (title_image,
-		       font,
+      gdk_draw_layout (title_image,
 		       gstones_view->style->black_gc,
-		       30, GAME_ROWS*STONE_SIZE-30,
-		       tmp->data,
-		       strlen (tmp->data));
+		       30, 
+                       GAME_ROWS*STONE_SIZE-30-height*3-height/2,
+                       layout);
+
+      pango_layout_set_text( layout, 
+                             game->title,
+                             strlen (_(game->title)));
+
+      gdk_draw_layout (title_image,
+		       gstones_view->style->black_gc,
+		       30, 
+                       GAME_ROWS*STONE_SIZE-30-height*2-height/2,
+                       layout);
+
+      pango_layout_set_text( layout, 
+                             _(cavename),
+                             strlen (_(cavename)));
+
+      gdk_draw_layout (title_image,
+		       gstones_view->style->black_gc,
+		       30, 
+                       GAME_ROWS*STONE_SIZE-30-height,
+                       layout);
+
+      pango_layout_set_text( layout, 
+                             tmp->data,
+                             strlen (tmp->data));
+
+      gdk_draw_layout (title_image,
+		       gstones_view->style->black_gc,
+		       30, 
+                       GAME_ROWS*STONE_SIZE-30,
+                       layout);
 
-      gdk_font_unref (font);
     }  
 
   /* Redraw the game widget.  */
@@ -470,19 +492,27 @@ curtain_ready (ViewCurtainMode mode)
   switch (mode)
     {
     case VIEW_CURTAIN_OPEN:  
+
       if (curtain_cave)
 	{
+	  (GSTONES_VIEW (gstones_view))->curtain_display_mode= 
+	     CURTAIN_DISPLAY_NONE;
+
 	  state= STATE_WAITING_TO_START;
 	  gtk_timeout_add (START_DELAY, start_cave_delay_timeout, curtain_cave);
 	}
       else
-	state= STATE_TITLE;
+	{
+  	  play_title_music();
+	  state= STATE_TITLE;
+	}
       break;
       
 
     case VIEW_CURTAIN_CLOSED:
       /* If the iteration has been running, we stop it now.  */
-      gtk_timeout_remove (iteration_timeout);
+      if (iteration_timeout) gtk_timeout_remove (iteration_timeout);
+      iteration_timeout=0;
       
       /* An existing cave must be deleted.  */
       if (cave)
@@ -508,6 +538,7 @@ curtain_ready (ViewCurtainMode mode)
 	view_display_image (GSTONES_VIEW (gstones_view), title_image);
       
       break;
+      default:
     }
 }
 
@@ -593,7 +624,14 @@ countdown_timeout_function (gpointer data)
 
 	  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
 	  gnome_app_flash (GNOME_APP (app), _("Congratulations, you win!"));
+
+
 	}
+      else
+	{
+	  if (newcave->is_intermission) player_inc_lives (player, 1);
+	}
+
     }
   return FALSE;
 }
@@ -610,7 +648,8 @@ countdown_start (GStonesCave *cave)
 {
   /* When showing the countdown, there is no iteration in the
      background anymore.  */
-  gtk_timeout_remove (iteration_timeout);
+  if (iteration_timeout) gtk_timeout_remove (iteration_timeout);
+  iteration_timeout=0;
 
   state    = STATE_COUNTDOWN;
   
@@ -636,9 +675,10 @@ void
 joystick_set_properties (guint32 deviceid, gfloat switch_level)
 {
   joystick_deviceid= deviceid;
+#if 0
   if (joystick_deviceid != GDK_CORE_POINTER)
     gdk_input_set_mode (joystick_deviceid, GDK_MODE_SCREEN);
-
+#endif
   joystick_switch_level= switch_level;
 }
 
@@ -648,6 +688,7 @@ joystick_get_information (gint *x_direction, gint *y_direction)
 {
   /* FIXME: This function should only return a joystick movement, if
      the game_widget has focus.  */
+#if 0
   if (joystick_deviceid != GDK_CORE_POINTER && joystick_has_focus)
     {
       gdouble x;
@@ -686,6 +727,7 @@ joystick_get_information (gint *x_direction, gint *y_direction)
       if (x_direction) *x_direction= xdir;
       if (y_direction) *y_direction= ydir;
     }
+#endif
 }
 
 
@@ -708,10 +750,10 @@ joystick_set_widget (GtkWidget *widget)
   
   gtk_widget_set_events (widget, gtk_widget_get_events (widget) | 
 			 GDK_FOCUS_CHANGE);
-  gtk_signal_connect (GTK_OBJECT (widget), "focus_in_event",
-		      (GtkSignalFunc) joystick_focus_change_event, 0);
-  gtk_signal_connect (GTK_OBJECT (widget), "focus_out_event",
-		      (GtkSignalFunc) joystick_focus_change_event, 0);
+  g_signal_connect (GTK_OBJECT (widget), "focus_in_event",
+                    (GtkSignalFunc) joystick_focus_change_event, 0);
+  g_signal_connect (GTK_OBJECT (widget), "focus_out_event",
+                    (GtkSignalFunc) joystick_focus_change_event, 0);
 
   joystick_widget= widget;
 }
@@ -743,9 +785,16 @@ iteration_timeout_function (gpointer data)
   
   if (!(flags & CAVE_FINISHED) && (cave->flags & CAVE_FINISHED))
     {
+      
+      if (!(cave->flags & CAVE_PLAYER_EXISTS) )
+	{
+          player_inc_lives (player, -1);
+	  /* No score for extra time */
+	  cave->timer=0;
+	}
+
       if (!(cave->flags & CAVE_PLAYER_EXISTS) && !cave->is_intermission)
 	{
-	  player_inc_lives (player, -1);
 	  
 	  if (player->lives != 0)
 	    { 
@@ -811,9 +860,10 @@ iteration_start (GStonesCave *newcave)
 void
 load_game (const gchar *filename, guint _start_cave)
 {
+
   char         buffer[256];
   GStonesGame *newgame;
-  
+
   g_return_if_fail (filename);
   
   /* We don't need to load a game twice.  */
@@ -831,8 +881,10 @@ load_game (const gchar *filename, guint _start_cave)
   if (newgame)
     {
       /* Remove all running timeouts.  */
-      gtk_timeout_remove (iteration_timeout);
-      gtk_timeout_remove (countdown_timeout);
+      if (iteration_timeout) gtk_timeout_remove (iteration_timeout);
+      iteration_timeout=0;
+      if (countdown_timeout) gtk_timeout_remove (countdown_timeout);
+      countdown_timeout=0;
 
       /* Set display into title mode.  */
       view_display_image (GSTONES_VIEW (gstones_view), title_image);
@@ -860,6 +912,7 @@ load_game (const gchar *filename, guint _start_cave)
       sprintf (buffer, "Game '%s' loaded.", filename);
       gnome_app_flash (GNOME_APP (app), buffer);
     }
+
 }
 
 
@@ -874,6 +927,9 @@ game_start_cb (GtkWidget *widget, gpointer data)
   GList       *tmp = NULL;
   GStonesCave *cave= NULL;
   
+
+  stop_title_music();
+
   if (!game) return;
   
   /* Initialize the player information.  */
@@ -889,6 +945,13 @@ game_start_cb (GtkWidget *widget, gpointer data)
 }
 
 
+static void
+game_stop_cb (GtkWidget *widget, gpointer data)
+{
+    curtain_start (NULL);
+}
+
+
 static void
 game_pause_cb (GtkWidget *widget, gpointer data)
 {
@@ -915,6 +978,7 @@ static void
 quit_cb (GtkWidget *widget, gpointer data)
 {
   preferences_save_global ();
+  sound_close();
 
   exit (0);
 }
@@ -931,17 +995,37 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
   GtkWidget *about= NULL;
+  GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
     "Carsten Schaar <nhadcasc@fs-maphy.uni-hannover.de>",
     NULL
   };
-  
+  gchar *documenters[] = {
+                          NULL
+                         };
+  /* Translator credits */
+  gchar *translator_credits = _("translator_credits");
+
+  {
+	  char *filename = NULL;
+
+	  filename = gnome_program_locate_file (NULL,
+			  GNOME_FILE_DOMAIN_PIXMAP,  ("gnome-stones.png"),
+			  TRUE, NULL);
+	  if (filename != NULL)
+	  {
+		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		  g_free (filename);
+	  }
+  }
   about= gnome_about_new (_("Gnome-Stones"), VERSION,
 			  "(C) 1998 Carsten Schaar",
-			  authors,
 			  _("A game."),
-			  NULL);
+			  (const char **)authors,
+                          (const char **)documenters,
+                          strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			  pixbuf);
   gtk_widget_show (about);
 }
 
@@ -953,12 +1037,13 @@ about_cb (GtkWidget *widget, gpointer data)
 
 static GnomeUIInfo game_menu[]= {
   GNOMEUIINFO_MENU_NEW_GAME_ITEM(game_start_cb, NULL),
+  GNOMEUIINFO_MENU_END_GAME_ITEM(game_stop_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_MENU_PAUSE_GAME_ITEM (game_pause_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_MENU_SCORES_ITEM(show_scores_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
+  GNOMEUIINFO_MENU_QUIT_ITEM(quit_cb, NULL),
   GNOMEUIINFO_END
 };
 
@@ -1011,7 +1096,8 @@ scan_private_game_directory (void)
 static gboolean
 scan_public_plugin_directory (void)
 {
-  char *dir= gnome_unconditional_libdir_file ("gnome-stones/objects/");
+  char *dir= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR, 
+                                        "gnome-stones/objects/", FALSE, NULL);
 
   plugin_load_plugins_in_dir (dir);
 
@@ -1071,6 +1157,8 @@ StartupSequence startup_sequence[]=
     preferences_restore,
     N_("Restoring preferences...")
   }
+
+
 };
 
 
@@ -1087,7 +1175,7 @@ static gint startup_function (gpointer data)
   
   startup_sequence[index].function ();
   
-  gnome_appbar_set_progress (GNOME_APPBAR (statusbar),
+  gnome_appbar_set_progress_percentage (GNOME_APPBAR (statusbar),
 			     (gfloat) (index+1)/(gfloat) max);
   index++;
 
@@ -1101,6 +1189,20 @@ static gint startup_function (gpointer data)
 }
 
 
+/************************************************************************/
+/* exit function */
+
+/* FIXME: too many different exit/quit functions */
+
+
+void
+gstones_exit (GnomeClient *client, gpointer client_data)
+{
+  sound_close (); 
+  exit (0);
+}
+
+
 
 /*****************************************************************************/
 /* Main function.  */
@@ -1109,14 +1211,16 @@ static gint startup_function (gpointer data)
 int
 main (int argc, char *argv[])
 {
+
   GtkWidget *frame= NULL;
   GtkWidget *vbox = NULL;
   GtkWidget *table= NULL;
   
   gnome_score_init (APP_NAME);
 
-  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-  textdomain (PACKAGE);
+  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
 
   gnome_init_with_popt_table (APP_NAME, VERSION, argc, argv, options, 0, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-stones.png");
@@ -1158,13 +1262,13 @@ main (int argc, char *argv[])
   
   gtk_widget_set_events (app, gtk_widget_get_events (app) | GAME_EVENTS);
 
-  gtk_signal_connect (GTK_OBJECT (app), "key_press_event",
+  g_signal_connect (GTK_OBJECT (app), "key_press_event",
 		      GTK_SIGNAL_FUNC (game_widget_key_press_callback), 0);
-  gtk_signal_connect (GTK_OBJECT (app), "key_release_event",
+  g_signal_connect (GTK_OBJECT (app), "key_release_event",
 		      GTK_SIGNAL_FUNC (game_widget_key_release_callback), 0);
-  gtk_signal_connect (GTK_OBJECT (app), "delete_event",
+  g_signal_connect (GTK_OBJECT (app), "delete_event",
 		      GTK_SIGNAL_FUNC (gtk_widget_destroy), 0);
-  gtk_signal_connect (GTK_OBJECT (app), "destroy",
+  g_signal_connect (GTK_OBJECT (app), "destroy",
 		      GTK_SIGNAL_FUNC (gtk_main_quit), 0);
 
   joystick_set_widget (app);
@@ -1174,15 +1278,21 @@ main (int argc, char *argv[])
   gtk_widget_show (app);
 
   title_image_load ();
-  gdk_pixmap_ref (title_image);
+
   view_display_image (GSTONES_VIEW (gstones_view), title_image);
 
   session_management_init ();
 
   gtk_idle_add (startup_function, NULL);
 
+  sound_init ();
+
+  play_title_music();
+
   gtk_main ();
 
+  sound_close ();
+
   return 0;
 }
 
