@@ -9,20 +9,16 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <gconf/gconf-client.h>
 #include <string.h>
 
 #include "minefield.h"
 #include "games-clock.h"
 
-#include "face-worried.xpm"
-#include "face-smile.xpm"
-#include "face-cool.xpm"
-#include "face-sad.xpm"
-#include "face-win.xpm"
-
 static GtkWidget *mfield;
 static GtkWidget *pref_dialog;
 static GtkWidget *rbutton;
+static GConfClient *conf_client;
 GtkWidget *window;
 GtkWidget *flabel;
 GtkWidget *xentry;
@@ -35,10 +31,10 @@ GtkWidget *cframe;
 GtkWidget *clk;
 GtkWidget *pm_win, *pm_sad, *pm_smile, *pm_cool, *pm_worried, *pm_current;
 GtkWidget *face_box;
-gint ysize=-1, xsize=-1;
-gint nmines=-1;
-gint fsize=-1, fsc;
-gint minesize=-1;
+gint ysize = -1, xsize = -1;
+gint nmines = -1;
+gint fsize = -1, fsc;
+gint minesize = -1;
 
 char *fsize2names[] = {
 	N_("Tiny"),
@@ -47,6 +43,23 @@ char *fsize2names[] = {
 	N_("Custom"),
 };
 
+static GtkWidget *
+image_widget_setup (char *name)
+{
+	GdkPixbuf *pixbuf = NULL;
+	char *filename = NULL;
+
+	filename = gnome_program_locate_file (NULL,
+			GNOME_FILE_DOMAIN_PIXMAP, name,
+			TRUE, NULL);
+	if (filename != NULL)
+		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+
+	g_free (filename);
+
+	return gtk_image_new_from_pixbuf (pixbuf);
+}
+
 void show_face(GtkWidget *pm)
 {
         if (pm_current == pm) return;
@@ -67,10 +80,10 @@ void quit_game(GtkWidget *widget, gpointer data)
 
 void set_flabel(GtkMineField *mfield)
 {
-	char val[16];
+	char *val;
 
-	sprintf(val, "%d/%d", mfield->flags, mfield->mcount);
-	gtk_label_set(GTK_LABEL(flabel), val);
+	val = g_strdup_printf ("%d/%d", mfield->flag_count, mfield->mcount);
+	gtk_label_set_text (GTK_LABEL(flabel), val);
 }
 
 void
@@ -96,7 +109,6 @@ void new_game(GtkWidget *widget, gpointer data)
 
         show_face(pm_smile);
 	gtk_minefield_restart(GTK_MINEFIELD(mfield));
-	gtk_widget_draw(mfield, NULL);
 	set_flabel(GTK_MINEFIELD(mfield));
 
 	gtk_widget_hide (rbutton);
@@ -111,6 +123,8 @@ void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 	gtk_widget_hide (mfield);
 	gtk_widget_show (rbutton);
 
+	gtk_widget_grab_focus(rbutton);
+
 	games_clock_stop(GAMES_CLOCK(clk)); 
 }
 
@@ -133,6 +147,8 @@ void lose_game(GtkWidget *widget, gpointer data)
 {
         show_face(pm_sad);
 
+	gtk_widget_grab_focus(mbutton);
+
         games_clock_stop(GAMES_CLOCK(clk));
 }
 
@@ -145,6 +161,8 @@ void win_game(GtkWidget *widget, gpointer data)
 
         games_clock_stop(GAMES_CLOCK(clk));
 
+	gtk_widget_grab_focus(mbutton);
+
         show_face(pm_win);
 
 	if(fsize<3) {
@@ -215,6 +233,7 @@ void
 about(GtkWidget *widget, gpointer data)
 {
         static GtkWidget *about;
+	GdkPixbuf *pixbuf = NULL;
 
         const gchar *authors[] = {
 		N_("Code: Pista"),
@@ -225,7 +244,7 @@ about(GtkWidget *widget, gpointer data)
 	const gchar *documenters[] = {
                 NULL
         };
-	const gchar *translator_credits = _("");
+	const gchar *translator_credits = _("translator_credits");
 	
 	if (about) {
 		gdk_window_raise (about->window);
@@ -233,23 +252,33 @@ about(GtkWidget *widget, gpointer data)
 		return;
 	}
 
-#ifdef ENABLE_NLS
        {
             int i=0;
             while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
        }
-#endif
+       {
+	       char *filename = NULL;
+
+	       filename = gnome_program_locate_file (NULL,
+			       GNOME_FILE_DOMAIN_PIXMAP,  ("gnome-gnomine.png"),
+			       TRUE, NULL);
+	       if (filename != NULL)
+	       {
+		       pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		       g_free (filename);
+	       }
+       }
 
         about = gnome_about_new (_("Gnome Mines"), VERSION,
 				 _("(C) 1997-1999 the Free Software Foundation"),
 				 _("Minesweeper clone"),
 				 (const char **)authors,
 				 (const char **)documenters,
-                                 (const char *)translator_credits,
-				 NULL);
-	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 pixbuf);
+	g_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
-	gnome_dialog_set_parent (GNOME_DIALOG (about), GTK_WINDOW (window));
+	gtk_window_set_transient_for(GTK_WINDOW (about), GTK_WINDOW (window));
         gtk_widget_show (about);
 }
 
@@ -264,26 +293,12 @@ void size_radio_callback(GtkWidget *widget, gpointer data)
 	fsc = GPOINTER_TO_INT (data);
 
 	gtk_widget_set_sensitive(cframe, fsc == 3);
-
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
-static void help_cb (GtkWidget * widget, gpointer data)
-{
-#if 0
-  GnomeHelpMenuEntry help_entry = { "gnome-mines", "menubar.html" };
-
-  gnome_help_display (NULL, &help_entry);
-#endif
-}
-
-static void apply_cb (GtkWidget *widget, gint pagenum, gpointer data)
+static void apply_cb (GtkDialog *widget, gint response, gpointer data)
 {
         guint oldxsize, oldysize, oldnmines, oldfsize, oldminesize;
 
-	if (pagenum != -1)
-		return;
-  
 	oldxsize = xsize;
 	oldysize = ysize;
 	oldnmines = nmines;
@@ -304,25 +319,22 @@ static void apply_cb (GtkWidget *widget, gint pagenum, gpointer data)
 		new_game(mfield, NULL);
 	}
 
-	gnome_config_set_int("/gnomine/geometry/xsize",  xsize);
-	gnome_config_set_int("/gnomine/geometry/ysize",  ysize);
-	gnome_config_set_int("/gnomine/geometry/nmines", nmines);
-	gnome_config_set_int("/gnomine/geometry/minesize", minesize);
-	gnome_config_set_int("/gnomine/geometry/mode",   fsize);
-	gnome_config_sync();
-}
+	gconf_client_set_int (conf_client, "/apps/gnomine/geometry/xsize",
+			xsize, NULL);
+	gconf_client_set_int (conf_client, "/apps/gnomine/geometry/ysize",
+			ysize, NULL);
+	gconf_client_set_int (conf_client, "/apps/gnomine/geometry/nmines",
+			nmines, NULL);
+	gconf_client_set_int (conf_client, "/apps/gnomine/geometry/minesize",
+			minesize, NULL);
+	gconf_client_set_int (conf_client, "/apps/gnomine/geometry/mode",
+			fsize, NULL);
 
-void prop_box_changed_callback (GtkWidget *widget, gpointer data)
-{
-	if (!pref_dialog)
-		return;
-
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
+	gtk_widget_destroy (GTK_WIDGET(widget));
 }
 
 void preferences_callback (GtkWidget *widget, gpointer data)
 {
-	GtkWidget *label;
 	GtkWidget *table;
 	GtkWidget *frame;
 	GtkWidget *vbox;
@@ -331,33 +343,30 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 	GtkWidget *table2;
 	GtkWidget *label2;
         GtkObject *adj;
-        gchar numstr[8];
+        char *numstr;
 	
 	if (pref_dialog)
 		return;
 
-	label = gtk_label_new (_("Game"));
-	gtk_widget_show (label);
-
 	table = gtk_table_new (2, 2, FALSE);
-	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_widget_show (table);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD);
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	frame = gtk_frame_new (_("Field size"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
 	gtk_widget_show (frame);
 
 	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 	gtk_widget_show (vbox);
 
 	button = gtk_radio_button_new_with_label(NULL, _("Tiny"));
 	if (fsize == 0)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (size_radio_callback), (gpointer) 0);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
         gtk_widget_show(button);
@@ -368,7 +377,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 	if (fsize == 1)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (size_radio_callback), (gpointer) 1);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
         gtk_widget_show (button);
@@ -379,7 +388,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 	if (fsize == 2)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (size_radio_callback), (gpointer) 2);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
         gtk_widget_show(button);
@@ -390,7 +399,7 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 	if (fsize == 3)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+	g_signal_connect (GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (size_radio_callback), (gpointer) 3);
 	gtk_box_pack_start (GTK_BOX (vbox), button, TRUE, TRUE, 0);
         gtk_widget_show(button);
@@ -401,12 +410,12 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 			GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
 	cframe = gtk_frame_new (_("Custom size"));
-	gtk_container_border_width (GTK_CONTAINER (cframe), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (cframe), 0);
 	gtk_widget_set_sensitive (cframe, fsize == 3);
 	gtk_widget_show (cframe);
 
 	table2 = gtk_table_new (3, 2, FALSE);
-	gtk_container_border_width (GTK_CONTAINER (table2), GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (table2), GNOME_PAD);
 	gtk_widget_show (table2);
 	gtk_table_set_row_spacings (GTK_TABLE (table2), GNOME_PAD);
 
@@ -417,14 +426,12 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
 	xentry = gtk_entry_new ();
-	gtk_widget_set_usize (xentry, 50, -1);
+	gtk_widget_set_size_request (xentry, 50, -1);
 	gtk_table_attach (GTK_TABLE (table2), xentry, 1, 2, 0, 1, 0, GTK_EXPAND
 			| GTK_FILL, 0, 0);
-	sprintf(numstr, "%d", xsize);
+	numstr = g_strdup_printf ("%d", xsize);
 	gtk_entry_set_text(GTK_ENTRY(xentry),numstr);
 	gtk_widget_show (xentry);
-	gtk_signal_connect (GTK_OBJECT (xentry), "key_press_event",
-			GTK_SIGNAL_FUNC (prop_box_changed_callback), NULL);
 
 	label2 = gtk_label_new (_("Vertical:"));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
@@ -433,14 +440,12 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
 	yentry = gtk_entry_new ();
-	gtk_widget_set_usize (yentry, 50, -1);
+	gtk_widget_set_size_request (yentry, 50, -1);
 	gtk_table_attach (GTK_TABLE (table2), yentry, 1, 2, 1, 2, 0, GTK_EXPAND
 			| GTK_FILL, 0, 0);
-	sprintf(numstr, "%d", ysize);
+	numstr = g_strdup_printf("%d", ysize);
 	gtk_entry_set_text(GTK_ENTRY(yentry),numstr);
 	gtk_widget_show (yentry);
-	gtk_signal_connect (GTK_OBJECT (yentry), "key_press_event",
-			GTK_SIGNAL_FUNC (prop_box_changed_callback), NULL);
 
 	label2 = gtk_label_new (_("Number of mines:"));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
@@ -449,14 +454,12 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
 	mentry = gtk_entry_new ();
-	gtk_widget_set_usize (mentry, 50, -1);
+	gtk_widget_set_size_request (mentry, 50, -1);
 	gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, GTK_FILL, GTK_EXPAND
 			| GTK_FILL, 0, 0);
-	sprintf(numstr, "%d", nmines);
+	numstr = g_strdup_printf ("%d", nmines);
 	gtk_entry_set_text(GTK_ENTRY(mentry),numstr);
 	gtk_widget_show (mentry);
-	gtk_signal_connect (GTK_OBJECT (mentry), "key_press_event",
-			GTK_SIGNAL_FUNC (prop_box_changed_callback), NULL);
 
 	gtk_container_add (GTK_CONTAINER (cframe), table2);
 
@@ -472,42 +475,28 @@ void preferences_callback (GtkWidget *widget, gpointer data)
 
         adj = gtk_adjustment_new(minesize, 2, 99, 1, 5, 10);
 	sentry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 10, 0);
-#if 0	
-        gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(sentry),
-					  GTK_UPDATE_ALWAYS
- ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
-					  | GTK_UPDATE_SNAP_TO_TICKS
- endif
-					  );
- ifdef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
-	gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(sentry), 1);
- endif
-#endif
-	gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC
-			(prop_box_changed_callback), NULL);
+
 	gtk_box_pack_start (GTK_BOX (hbox), sentry, TRUE, TRUE, 0);
 	gtk_widget_show(sentry);
 
 	gtk_table_attach (GTK_TABLE (table), hbox, 0, 1, 1, 2, GTK_EXPAND |
 			GTK_FILL, 0, 0, 0);
 
-	pref_dialog = gnome_property_box_new ();
-	gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog),
-			GTK_WINDOW (window));
-	gtk_window_set_title (GTK_WINDOW (pref_dialog),
-			_("Gnome Mine Preferences"));
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
+	pref_dialog = gtk_dialog_new_with_buttons (_("Gnome Mine Preferences"),
+			GTK_WINDOW (window),
+			0,
+			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+			NULL);
+
+	g_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
 			GTK_SIGNAL_FUNC (gtk_widget_destroyed), &pref_dialog);
 
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (pref_dialog),
-			table, label);
+	gtk_container_add (GTK_CONTAINER(GTK_DIALOG(pref_dialog)->vbox),
+			table);
 
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "apply", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (pref_dialog), "response", GTK_SIGNAL_FUNC
 			(apply_cb), NULL);
 
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "help", GTK_SIGNAL_FUNC
-			(help_cb), NULL);
-
         fsc = fsize;
 
 	gtk_widget_show (pref_dialog);
@@ -518,7 +507,7 @@ GnomeUIInfo gamemenu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_SCORES_ITEM(top_ten, NULL),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_EXIT_ITEM(quit_game, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM(quit_game, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -544,9 +533,10 @@ GnomeUIInfo mainmenu[] = {
 static char *
 nstr (int n)
 {
-	char buf[20];
-	sprintf (buf, "%d", n);
-	return strdup (buf);
+	char *buf;
+
+	buf = g_strdup_printf ("%d", n);
+	return buf;
 }
 
 static int
@@ -590,7 +580,7 @@ save_state (GnomeClient        *client,
 
 
 
-static int xpos=-1, ypos=-1;
+static int xpos = -1, ypos = -1;
 
 static struct poptOption options[] = {
   {NULL, 'x', POPT_ARG_INT, &xsize, 0, N_("Width of grid"), N_("X")},
@@ -621,35 +611,50 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-        gnome_init_with_popt_table("gnomine", VERSION, argc, argv,
-				   options, 0, NULL);
+	gnome_program_init ("gnomine", VERSION,
+			LIBGNOMEUI_MODULE,
+			argc, argv,
+			GNOME_PARAM_POPT_TABLE, options,
+			NULL);
+
+	/* Get the default GConfClient */
+	conf_client = gconf_client_get_default ();
 
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnomine.png");
 	client = gnome_master_client ();
-	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
+	g_signal_connect (GTK_OBJECT (client), "save_yourself",
 			    GTK_SIGNAL_FUNC (save_state), argv[0]);
 
 	if (xpos > 0 || ypos > 0)
-	  gtk_widget_set_uposition (window, xpos, ypos);
+	  gdk_window_move (GTK_WIDGET(window)->window, xpos, ypos);
 		
 	if (xsize == -1)
-	  xsize  = gnome_config_get_int("/gnomine/geometry/xsize=16");
+		xsize = gconf_client_get_int (conf_client,
+				"/apps/gnomine/geometry/xsize",
+				NULL);
 	if (ysize == -1)
-	  ysize = gnome_config_get_int("/gnomine/geometry/ysize=16");
+		ysize = gconf_client_get_int (conf_client,
+				"/apps/gnomine/geometry/ysize",
+				NULL);
 	if (nmines == -1)
-	  nmines = gnome_config_get_int("/gnomine/geometry/nmines=40");
+		nmines = gconf_client_get_int (conf_client,
+				"/apps/gnomine/geometry/nmines",
+				NULL);
 	if (minesize == -1){
-	  minesize = gnome_config_get_int("/gnomine/geometry/minesize=17");
+		minesize = gconf_client_get_int (conf_client,
+				"/apps/gnomine/geometry/minesize",
+				NULL);
 	  /* XXX is this necessary, verify_ranges() is just below. */
 	  if (minesize < 0)
 	    minesize = 1;
 	}
 	if (fsize == -1)
-	  fsize  = gnome_config_get_int("/gnomine/geometry/mode=0");
+		fsize = gconf_client_get_int (conf_client,
+				"/apps/gnomine/geometry/mode",
+				NULL);
 
 	verify_ranges ();
 
-#ifdef ENABLE_NLS 
 #define ELEMENTS(x) (sizeof(x) / sizeof(x[0])) 
 	{
 		int i;
@@ -660,18 +665,17 @@ main (int argc, char *argv[])
 		for (i = 0; i < ELEMENTS(helpmenu); i++)
 			helpmenu[i].label = gettext(helpmenu[i].label);
 	}
-#endif /* ENABLE_NLS */
 
         window = gnome_app_new("gnomine", _("Gnome Mines"));
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
-	gtk_window_set_policy(GTK_WINDOW (window), TRUE, TRUE, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW(window), FALSE);
 
 	appbar = GNOME_APPBAR (gnome_appbar_new(FALSE, FALSE, FALSE));
 	gnome_app_set_statusbar(GNOME_APP (window), GTK_WIDGET (appbar));
 	
-        gtk_signal_connect(GTK_OBJECT(window), "delete_event",
+        g_signal_connect(GTK_OBJECT(window), "delete_event",
                            GTK_SIGNAL_FUNC(quit_game), NULL);
-	gtk_signal_connect(GTK_OBJECT(window), "focus_out_event",
+	g_signal_connect(GTK_OBJECT(window), "focus_out_event",
 			    GTK_SIGNAL_FUNC(focus_out_cb), NULL);
 
         all_boxes = gtk_vbox_new(FALSE, 0);
@@ -684,20 +688,20 @@ main (int argc, char *argv[])
         pm_current = NULL;
 
 	mbutton = gtk_button_new();
-	gtk_signal_connect(GTK_OBJECT(mbutton), "clicked",
+	g_signal_connect(GTK_OBJECT(mbutton), "clicked",
                            GTK_SIGNAL_FUNC(new_game), NULL);
-        gtk_widget_set_usize(mbutton, 38, 38);
+        gtk_widget_set_size_request (mbutton, 38, 38);
 	gtk_table_attach(GTK_TABLE(button_table), mbutton, 1, 2, 0, 1,
 			 0, 0, 5, 5);
 
 	face_box = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(mbutton), face_box);
 	
-	pm_win     = gnome_pixmap_new_from_xpm_d (face_win_xpm);
-	pm_sad     = gnome_pixmap_new_from_xpm_d (face_sad_xpm);
-	pm_smile   = gnome_pixmap_new_from_xpm_d (face_smile_xpm);
-	pm_cool    = gnome_pixmap_new_from_xpm_d (face_cool_xpm);
-	pm_worried = gnome_pixmap_new_from_xpm_d (face_worried_xpm);
+	pm_win     = image_widget_setup ("gnomine/face-win.xpm");
+	pm_sad     = image_widget_setup ("gnomine/face-sad.xpm");
+	pm_smile   = image_widget_setup ("gnomine/face-smile.xpm");
+	pm_cool    = image_widget_setup ("gnomine/face-cool.xpm");
+	pm_worried = image_widget_setup ("gnomine/face-worried.xpm");
 
         gtk_box_pack_start(GTK_BOX(face_box), pm_win, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(face_box), pm_sad, FALSE, FALSE, 0);
@@ -718,39 +722,34 @@ main (int argc, char *argv[])
 			  0, 0);
         gtk_widget_show (align);
   
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
-	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
-	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
-
 	box = gtk_vbox_new(FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (align), box);
 	mfield = gtk_minefield_new();
-	gtk_box_pack_start(GTK_BOX(box), mfield, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(box), mfield, TRUE, TRUE, 0);
 
 	rbutton = gtk_button_new_with_label ("Press to resume");
-	gtk_signal_connect (GTK_OBJECT(rbutton), "released", 
+	g_signal_connect (GTK_OBJECT(rbutton), "clicked", 
 			    GTK_SIGNAL_FUNC (resume_game_cb), NULL);
-	gtk_box_pack_start(GTK_BOX(box), rbutton, TRUE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(box), rbutton, TRUE, TRUE, 0);
 	gtk_widget_show (box);
 
         setup_mode(mfield, fsize);
 	
-	gtk_signal_connect(GTK_OBJECT(mfield), "marks_changed",
+	g_signal_connect(GTK_OBJECT(mfield), "marks_changed",
 			   GTK_SIGNAL_FUNC(marks_changed), NULL);
-	gtk_signal_connect(GTK_OBJECT(mfield), "explode",
+	g_signal_connect(GTK_OBJECT(mfield), "explode",
 			   GTK_SIGNAL_FUNC(lose_game), NULL);
-	gtk_signal_connect(GTK_OBJECT(mfield), "win",
+	g_signal_connect(GTK_OBJECT(mfield), "win",
 			   GTK_SIGNAL_FUNC(win_game), NULL);
-	gtk_signal_connect(GTK_OBJECT(mfield), "look",
+	g_signal_connect(GTK_OBJECT(mfield), "look",
 			   GTK_SIGNAL_FUNC(look_cell), NULL);
-	gtk_signal_connect(GTK_OBJECT(mfield), "unlook",
+	g_signal_connect(GTK_OBJECT(mfield), "unlook",
 			   GTK_SIGNAL_FUNC(unlook_cell), NULL);
 	
 	gtk_widget_show(mfield);
 
         status_table = gtk_table_new(1, 4, TRUE);
-	gtk_box_pack_start(GTK_BOX(all_boxes), status_table, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(all_boxes), status_table, FALSE, TRUE, 0);
 	label = gtk_label_new(_("Flags:"));
 	gtk_table_attach(GTK_TABLE(status_table), label,
 			 0, 1, 0, 1, 0, 0, 3, 3);
