@@ -40,6 +40,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "yahtzee.h"
@@ -106,8 +107,8 @@ CheerWinner(void)
                         ShowHighScores();
         }
 
-	ShowoffPlayer(GTK_CLIST(ScoreList),CurrentPlayer,0);
-	ShowoffPlayer(GTK_CLIST(ScoreList),winner,1);
+	ShowoffPlayer(ScoreList,CurrentPlayer,0);
+	ShowoffPlayer(ScoreList,winner,1);
 
         if (players[winner].name)
                 say(_("%s wins the game with %d points"),
@@ -126,12 +127,12 @@ NextPlayer(void)
         } 
         NumberOfRolls = 0;
 
-	ShowoffPlayer(GTK_CLIST(ScoreList),CurrentPlayer,0);
+	ShowoffPlayer(ScoreList,CurrentPlayer,0);
 
         if ( ++CurrentPlayer >= NumberOfPlayers )
                 CurrentPlayer = 0;
 
-	ShowoffPlayer(GTK_CLIST(ScoreList),CurrentPlayer,1);
+	ShowoffPlayer(ScoreList,CurrentPlayer,1);
 
         if (players[CurrentPlayer].name) {
                 if (players[CurrentPlayer].comp) {
@@ -175,8 +176,6 @@ ShowPlayer(int num, int field)
         int bonus = -1;
         int score;
         
-        gtk_clist_freeze(GTK_CLIST(ScoreList));
-
 	for (i = 0; i < NUM_FIELDS; ++i) {
                 
 		if (i == field || field == -1) {
@@ -190,8 +189,7 @@ ShowPlayer(int num, int field)
 				score = players[num].score[i];
                         else
                                 score = -1;
-                        update_score_cell(GTK_CLIST(ScoreList), 
-                                          line, num+1, score);
+                        update_score_cell(ScoreList, line, num+1, score);
                 }
 	}
         
@@ -203,14 +201,10 @@ ShowPlayer(int num, int field)
 		upper_tot += bonus;
 	}
         
-        update_score_cell(GTK_CLIST(ScoreList), R_BONUS, num+1, bonus);
-        update_score_cell(GTK_CLIST(ScoreList), R_UTOTAL, num+1, upper_tot);
-        update_score_cell(GTK_CLIST(ScoreList), R_LTOTAL, num+1, lower_tot);
-        update_score_cell(GTK_CLIST(ScoreList), R_GTOTAL, num+1, 
-                          upper_tot+lower_tot);
-        
-        gtk_clist_thaw(GTK_CLIST(ScoreList));
-
+        update_score_cell(ScoreList, R_BONUS, num+1, bonus);
+        update_score_cell(ScoreList, R_UTOTAL, num+1, upper_tot);
+        update_score_cell(ScoreList, R_LTOTAL, num+1, lower_tot);
+        update_score_cell(ScoreList, R_GTOTAL, num+1, upper_tot+lower_tot);
 }
 
 static gint 
@@ -227,11 +221,11 @@ GyahtzeeNewGame(void)
         int i;
 
         NewGame();
-        setup_clist(ScoreList);
+        setup_score_list(ScoreList);
 
 	for (i=0; i<NumberOfPlayers; i++)
-                ShowoffPlayer(GTK_CLIST(ScoreList),i,0);
-	ShowoffPlayer(GTK_CLIST(ScoreList),0,1);
+                ShowoffPlayer(ScoreList,i,0);
+	ShowoffPlayer(ScoreList,0,1);
 
         /* All players are computers, start game immediately */
         if (players[CurrentPlayer].comp) {
@@ -365,13 +359,15 @@ about(GtkWidget *widget, gpointer data)
         };
         /* Translator credits */
         gchar *translator_credits = _("translator_credits");
+	GdkPixbuf *pixbuf = NULL;
         
-#ifdef ENABLE_NLS
 	{
 		int i=0;
 		while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
 	}
-#endif
+
+	pixbuf = gdk_pixbuf_new_from_file (GNOMEPIXMAPDIR "/gnome-gtali.png",
+			NULL);
 
         about = gnome_about_new (appName, VERSION,
 				 _("(C) 1998 the Free Software Fundation"),
@@ -379,7 +375,7 @@ about(GtkWidget *widget, gpointer data)
 				 (const char **)authors,
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 NULL);
+				 pixbuf);
         gtk_widget_show (about);
 	return FALSE;
 }
@@ -418,7 +414,7 @@ GnomeUIInfo gamemenu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_SCORES_ITEM(score_callback, NULL),
 	GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_MENU_EXIT_ITEM(quit_game, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(quit_game, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -444,33 +440,40 @@ GnomeUIInfo mainmenu[] = {
 static void
 LoadDicePixmaps(void)
 {
-	GtkWidget *tmp;
+        GtkWidget *tmp;
+	GdkPixbuf *pixbuf;
+	const char **xpm_data[] = {
+		gnome_dice_1_xpm,
+		gnome_dice_2_xpm,
+		gnome_dice_3_xpm,
+		gnome_dice_4_xpm,
+		gnome_dice_5_xpm,
+		gnome_dice_6_xpm,
+		gnome_dice_none_xpm
+	};
 	int i, j;
 
-	/* Read in default dice */
-	dicePixmaps[0][0] = gnome_pixmap_new_from_xpm_d(gnome_dice_1_xpm);
-	dicePixmaps[0][1] = gnome_pixmap_new_from_xpm_d(gnome_dice_2_xpm);
-	dicePixmaps[0][2] = gnome_pixmap_new_from_xpm_d(gnome_dice_3_xpm);
-	dicePixmaps[0][3] = gnome_pixmap_new_from_xpm_d(gnome_dice_4_xpm);
-	dicePixmaps[0][4] = gnome_pixmap_new_from_xpm_d(gnome_dice_5_xpm);
-	dicePixmaps[0][5] = gnome_pixmap_new_from_xpm_d(gnome_dice_6_xpm);
-	dicePixmaps[0][6] = gnome_pixmap_new_from_xpm_d(gnome_dice_none_xpm);
-        
 	for (i=0; i<NUMBER_OF_PIXMAPS; i++) {
+		tmp = NULL;
 
-                /* Check for files w/pixmaps, override compiled defaults */
-                if (g_file_exists(dicefiles[i])) {
-                        tmp = gnome_pixmap_new_from_file(dicefiles[i]);
-                        if (tmp != NULL) { 
-                                gtk_widget_destroy(dicePixmaps[0][i]);
-                                dicePixmaps[0][i] = tmp;
-                        }
-                }
+		/* Check for files w/pixmaps, override compiled defaults */
+		if (g_file_test(dicefiles[i], G_FILE_TEST_EXISTS))
+			tmp = gtk_image_new_from_file(dicefiles[i]);
 
-                for (j=0; j<NUMBER_OF_DICE; j++) 
-                      dicePixmaps[j][i] = gnome_pixmap_new_from_gnome_pixmap
-                                            (GNOME_PIXMAP(dicePixmaps[0][i])); 
-        }
+		if (tmp != NULL) {
+			dicePixmaps[0][i] = tmp;
+		} else { /* Load default dice */
+			pixbuf = gdk_pixbuf_new_from_xpm_data(xpm_data[i]);
+			dicePixmaps[0][i] = gtk_image_new_from_pixbuf (pixbuf);
+			g_object_unref(pixbuf);
+		}
+
+		for (j=0; j<NUMBER_OF_DICE; j++) {
+			pixbuf = gtk_image_get_pixbuf(
+				GTK_IMAGE(dicePixmaps[0][i]));
+			dicePixmaps[j][i] = gtk_image_new_from_pixbuf(pixbuf);
+		}
+	}
 }
 
 
@@ -482,13 +485,9 @@ GyahtzeeCreateMainWindow(void)
 	GtkWidget *tmp;
 	int i, j;
 
-        gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, FALSE);
-        gtk_signal_connect(GTK_OBJECT(window), "delete_event",
-                           GTK_SIGNAL_FUNC(quit_game), NULL);
-
-	/* Want CList to show up w/o scroll bars */
-	gtk_widget_set_usize( GTK_WIDGET (window), 845,462);
-
+        gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
+        g_signal_connect(G_OBJECT(window), "delete_event",
+                         G_CALLBACK(quit_game), NULL);
 
 	/*---- Menus ----*/
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
@@ -530,10 +529,8 @@ GyahtzeeCreateMainWindow(void)
                                        gtk_widget_get_events(diceBox[i]) |
                                        GDK_BUTTON_PRESS_MASK );
                 
-                gtk_signal_connect( GTK_OBJECT(diceBox[i]), 
-                                    "button_press_event",
-                                    GTK_SIGNAL_FUNC(gnome_modify_dice),
-                                    &DiceValues[i] );
+                g_signal_connect(G_OBJECT(diceBox[i]), "button_press_event",
+                                 G_CALLBACK(gnome_modify_dice), &DiceValues[i]);
 
                 gtk_widget_show(dicePixmaps[i][0]);
                 gtk_widget_show(tmp);
@@ -542,15 +539,15 @@ GyahtzeeCreateMainWindow(void)
 	mbutton = gtk_button_new_with_label(_(" Roll ! "));
 	gtk_table_attach(GTK_TABLE(diceTable), mbutton, 0, 1, i, i+1,
 			 0, 0, 5, 5);
-	gtk_signal_connect (GTK_OBJECT (mbutton), "clicked",
-			    GTK_SIGNAL_FUNC (gnome_roll_dice), NULL);
+        g_signal_connect(G_OBJECT(mbutton), "clicked",
+                         G_CALLBACK(gnome_roll_dice), NULL);
 	gtk_widget_show(mbutton);
 	gtk_widget_show(diceTable);
         
-	/* Scores displayed in CList */
-        ScoreList = create_clist();
+	/* Scores displayed in score list */
+        ScoreList = create_score_list();
         gtk_box_pack_end(GTK_BOX(all_boxes), ScoreList, TRUE, TRUE, 0);
-        setup_clist(ScoreList);
+        setup_score_list(ScoreList);
         gtk_widget_show(ScoreList);
         
 	gtk_widget_show(all_boxes);
@@ -563,6 +560,9 @@ GyahtzeeCreateMainWindow(void)
 int
 main (int argc, char *argv[])
 {
+        GConfClient *client;
+        GError *err = NULL;
+        GSList *name_list = NULL;
         gchar *newname, *PrefLoc;
         gint i;
 
@@ -579,28 +579,61 @@ main (int argc, char *argv[])
         gnome_init_with_popt_table(appID, VERSION, argc, argv,
 				   yahtzee_options, 0, NULL);
         gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gtali.png");
-	NumberOfComputers = gnome_config_get_int("/gtali/Preferences/NumberOfComputerOpponents=5");
-	NumberOfHumans = gnome_config_get_int("/gtali/Preferences/NumberOfHumanOpponents=1");
- 	ExtraYahtzeeBonus = gnome_config_get_int("/gtali/Preferences/ExtraYahtzeeBonus=1");
- 	ExtraYahtzeeBonusVal = gnome_config_get_int("/gtali/Preferences/ExtraYahtzeeBonusVal=50");
- 	ExtraYahtzeeJoker = gnome_config_get_int("/gtali/Preferences/ExtraYahtzeeJoker=0");
+
+        client = gconf_client_get_default ();
+        NumberOfComputers = gconf_client_get_int(client, "/apps/gtali/NumberOfComputerOpponents", &err);
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
+        }
+
+	NumberOfHumans = gconf_client_get_int(client, "/apps/gtali/NumberOfHumanOpponents", &err);
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
+        }
+
+ 	ExtraYahtzeeBonus = gconf_client_get_int(client, "/apps/gtali/ExtraYahtzeeBonus", &err);
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
+        }
+
+ 	ExtraYahtzeeBonusVal = gconf_client_get_int(client, "/apps/gtali/ExtraYahtzeeBonusVal", &err);
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
+        }
+
+ 	ExtraYahtzeeJoker = gconf_client_get_int(client, "/apps/gtali/ExtraYahtzeeJoker", &err);
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
+        }
 
         /* Read in new player names */
-	for (i = 0; i < MAX_NUMBER_OF_PLAYERS; ++i) {
-                gchar *newname;
+        name_list = gconf_client_get_list(client, "/apps/gtali/PlayerNames",
+                                          GCONF_VALUE_STRING, &err);
 
-                PrefLoc = g_strdup_printf("/gtali/Preferences/PlayerName%1d",i+1);
-                newname = gnome_config_get_string_with_default(PrefLoc, NULL);
-                g_free(PrefLoc);
-
-                if (newname) {
-                        players[i].name = g_malloc(strlen(newname));
-                        if (players[i].name)
-                                strcpy(players[i].name,newname);
-                        g_free(newname);
-                }
+        if(err) {
+                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
+                g_error_free(err);
+                err = NULL;
         }
 
+        for(i = 0; i < MAX_NUMBER_OF_PLAYERS && name_list; i++) {
+                if(name_list->data)
+                        players[i].name = g_strdup(name_list->data);
+                
+                name_list = g_slist_next(name_list);
+        }
+        g_slist_free(name_list);
+
 	/* For some options, we don't want to play a game */
 	if (!GyahtzeeAbort) {
 
