@@ -57,6 +57,9 @@ int NumberOfRolls;
 int WinningScore;
 int DisplayComputerThoughts = 0;
 int OnlyShowScores = 0;
+int ExtraYahtzeeBonus = 1;
+int ExtraYahtzeeBonusVal = 50;
+int ExtraYahtzeeJoker = 0;
 int IsCheater;
 int CurrentPlayer;
 UndoInfo *gUndoInfo = NULL;
