@@ -9,6 +9,7 @@
  * The idea is originally from KDE's same game program.
  *
  */
+
 #include <sys/types.h>
 #include <string.h>
 #include <stdlib.h>
@@ -18,7 +19,8 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include <gdk_imlib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gconf/gconf-client.h>
 
 
 #define STONE_SIZE 40
@@ -32,7 +34,7 @@
 
 static GtkWidget *pref_dialog, *scorew, *markedw;
 static GtkWidget *app, *draw_area, *vb, *appbar;
-static GdkImlibImage *image;
+static GdkPixbuf *image;
 static GdkPixmap *stones, *mask;
 static int tagged_count = 0;
 static int ball_timeout_id = -1;
@@ -40,12 +42,11 @@ static int old_x = -1, old_y = -1;
 static int score;
 static gchar *scenario;
 static gint restarted;
-static gint debugging;
+static gboolean game_over = FALSE;
 
-static struct {
-	char *scenario;
-	int make_it_default;
-} selected_scenario = {0,0};
+/* Prefs */
+GConfClient *conf_client = NULL;
+char *selected_scenario = NULL;
 
 static struct ball {
 	int color;
@@ -57,9 +58,6 @@ static int nstones;
 static int ncolors;
 static int sync_stones = 0;
 
-/* This is used only while parsing arguments.  */
-static gchar *fname;
-
 #define mapx(x) (x)
 #define mapy(y) (STONE_LINES-1-(y))
 
@@ -71,8 +69,8 @@ draw_ball (int x, int y)
 	if (field [x][y].color){
 		by = STONE_SIZE * (field [x][y].color - 1);
 		bx = STONE_SIZE * (field [x][y].frame);
-		
-		gdk_draw_pixmap (draw_area->window,
+
+		gdk_draw_drawable (draw_area->window,
 				 draw_area->style->black_gc, stones,
 				 bx, by, x * STONE_SIZE, y * STONE_SIZE,
 				 STONE_SIZE, STONE_SIZE);
@@ -180,12 +178,13 @@ mark_balls (int x, int y)
 	tagged_count = flood_fill (x, y, field [x][y].color);
 	
 	if (tagged_count > 1) {
-		char b[3];
+		char *b;
 		ball_timeout_id = gtk_timeout_add (100, move_tagged_balls, 0);
-		sprintf (b, "%.2d", tagged_count);
-		gtk_label_set (GTK_LABEL(markedw), b);
+		b = g_strdup_printf ("%.2d", tagged_count);
+		gtk_label_set_text (GTK_LABEL(markedw), b);
+		g_free (b);
 	} else
-		gtk_label_set (GTK_LABEL(markedw), "00");
+		gtk_label_set_text (GTK_LABEL(markedw), "00");
 }
 
 static void
@@ -249,32 +248,24 @@ compress_x ()
 static void
 set_score (int new_score)
 {
-	char b [20];
+	char *b = NULL;
 	
 	score = new_score;
-	sprintf (b, "%.5d", score);
-	gtk_label_set (GTK_LABEL(scorew), b);
+	b = g_strdup_printf ("%.5d", score);
+	gtk_label_set_text (GTK_LABEL(scorew), b);
+	g_free (b);
 }
 
 static void
-show_scores ( gchar *title, guint pos )
+show_scores (guint pos)
 {
-	gnome_scores_display (title, "same-gnome", NULL, pos);
+	gnome_scores_display (_("The Same Gnome"), "same-gnome", NULL, pos);
 }
 
 static void
 game_top_ten_callback(GtkWidget *widget, gpointer data)
 {
-	show_scores(_("The Same Gnome"), 0);
-}
-
-static void
-end_of_game (char *title)
-{
-	int pos;
-
-	pos = gnome_score_log(score, NULL, TRUE);
-	show_scores(title, pos);
+	show_scores(0);
 }
 
 static void
@@ -282,6 +273,7 @@ check_game_over (void)
 {
 	int cleared=1;
 	int x,y;
+	int pos;
 	
 	for(x = 0; x < STONE_COLS; x++)
 		for(y = 0 ; y < STONE_LINES; y++) {
@@ -295,12 +287,13 @@ check_game_over (void)
 				if(field[x][y].color == field[x][y+1].color)
 					return;
 		}
-	if (cleared){
+
+	if (cleared)
 		set_score (score+1000);
-		end_of_game (_("The Same Gnome"));
-	}
-	else
-		end_of_game(_("The Same Gnome"));
+
+	pos = gnome_score_log(score, NULL, TRUE);
+	show_scores(pos);
+	game_over = TRUE;
 }
 
 static void
@@ -374,6 +367,7 @@ fill_board (void)
 static void
 new_game (void)
 {
+	game_over = FALSE;
 	fill_board ();
 	set_score (0);
 	gtk_widget_draw (draw_area, NULL);
@@ -395,56 +389,58 @@ load_scenario (char *fname)
         GdkColor bgcolor;
         GdkImage *tmpimage;
     
-	tmp = g_strconcat ( "same-gnome/", fname, NULL);
+	g_return_if_fail (fname != NULL);
 
-	fn = gnome_unconditional_pixmap_file ( tmp );
-	g_free( tmp );
+	fn = g_strconcat ( PIXMAPDIR, "/", fname, NULL);
 
-	if (!g_file_exists (fn)) {
-		char *message = g_strdup_printf (
+	if (!g_file_test (fn, G_FILE_TEST_EXISTS)) {
+		GtkWidget *box = gtk_message_dialog_new (GTK_WINDOW (app),
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
 			_("Could not find the theme:\n%s\n\n"
 			"Please check you Same Gnome instalation"), fn);
-		GtkWidget *w = gnome_error_dialog (message);
-		gnome_dialog_run_and_close (GNOME_DIALOG(w));
-		g_free (message);
+
+		gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_OK);
+		gtk_dialog_run (GTK_DIALOG (box));
+		gtk_widget_destroy (box);
 		exit (1);
 	}
 
-	if (scenario)
-		g_free (scenario);
-
+	g_free (scenario);
 	scenario = g_strdup(fname);
 
 	configure_sync (fname);
 
 	if (image)
-		gdk_imlib_destroy_image (image);
+		gdk_pixbuf_unref (image);
 
-	image = gdk_imlib_load_image (fn);
+	image = gdk_pixbuf_new_from_file (fn, NULL);
 
 	if (image == NULL) {
-		char *message = g_strdup_printf (
+		GtkWidget *box = gtk_message_dialog_new (GTK_WINDOW (app),
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
 			_("Same Gnome can't load the image file:\n%s\n\n"
 			 "Please check your Same Gnome installation"), fn);
-		GtkWidget *w = gnome_error_dialog (message);
-		gnome_dialog_run_and_close (GNOME_DIALOG(w));
-		g_free (message);
+
+		gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_OK);
+		gtk_dialog_run (GTK_DIALOG (box));
+		gtk_widget_destroy (box);
 		exit (1);
 	}
 
-	gdk_imlib_render (image, image->rgb_width, image->rgb_height);
+	gdk_pixbuf_render_pixmap_and_mask (image, &stones, &mask, 127);
 
-	stones = gdk_imlib_move_image (image);
-	mask = gdk_imlib_move_mask (image);
-
-        tmpimage = gdk_image_get(stones, 0, 0, 1, 1);
+        tmpimage = gdk_drawable_get_image (stones, 0, 0, 1, 1);
         bgcolor.pixel = gdk_image_get_pixel(tmpimage, 0, 0);
         gdk_window_set_background (draw_area->window, &bgcolor);
-        gdk_image_destroy(tmpimage);
+	gdk_image_unref (tmpimage);
   
 	g_free( fn );
 
-	nstones = image->rgb_width / STONE_SIZE;
+	nstones = gdk_pixbuf_get_width (image) / STONE_SIZE;
 /*	ncolors = image->rgb_height / STONE_SIZE; */
 	ncolors = 3;
 
@@ -452,32 +448,11 @@ load_scenario (char *fname)
 	gtk_widget_draw (draw_area, NULL);
 }
 
-static void
-set_selection (GtkWidget *widget, void *data)
-{
-	if (selected_scenario.scenario)
-		free (selected_scenario.scenario);
-
-	selected_scenario.scenario = strdup (data);
-}
-
-static void
-set_selection_def (GtkWidget *widget, gpointer *data)
-{
-	selected_scenario.make_it_default = GTK_TOGGLE_BUTTON (widget)->active;
-}
-
 static void
 create_same_board (char *fname)
 {
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-
 	draw_area = gtk_drawing_area_new ();
 
-        gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
-
 	gtk_widget_set_events (draw_area, gtk_widget_get_events (draw_area) | GAME_EVENTS);
 
 	gtk_box_pack_start_defaults (GTK_BOX(vb), draw_area);
@@ -489,7 +464,8 @@ create_same_board (char *fname)
 	gtk_drawing_area_size (GTK_DRAWING_AREA (draw_area),
 			       STONE_COLS  * STONE_SIZE,
 			       STONE_LINES * STONE_SIZE);
-	gtk_signal_connect (GTK_OBJECT(draw_area), "event", (GtkSignalFunc) area_event, 0);
+	g_signal_connect (G_OBJECT (draw_area), "event",
+			  G_CALLBACK(area_event), 0);
 }
 
 static void
@@ -499,20 +475,20 @@ game_new_callback (GtkWidget *widget, void *data)
 }
 
 static void
-free_str (GtkWidget *widget, void *data)
+set_selection (GtkWidget *widget, gpointer data)
 {
-	free (data);
+	load_scenario (data);
+	gconf_client_set_string (conf_client, "/apps/same-gnome/tileset", data, NULL);
 }
 
 static void
 fill_menu (GtkWidget *menu)
 {
 	struct dirent *e;
-	char *dname = gnome_unconditional_pixmap_file ("same-gnome");
 	DIR *dir;
         int itemno = 0;
 	
-	dir = opendir (dname);
+	dir = opendir (PIXMAPDIR);
 
 	if (!dir)
 		return;
@@ -528,60 +504,61 @@ fill_menu (GtkWidget *menu)
 			
 		item = gtk_menu_item_new_with_label (s);
 		gtk_widget_show (item);
-		gtk_menu_append (GTK_MENU(menu), item);
-		gtk_signal_connect (GTK_OBJECT(item), "activate",
-				    GTK_SIGNAL_FUNC (set_selection), s);
-		gtk_signal_connect (GTK_OBJECT(item), "destroy",
-				    GTK_SIGNAL_FUNC (free_str), s);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		g_signal_connect (G_OBJECT (item), "activate",
+				  G_CALLBACK (set_selection), s);
 	  
 	        if (!strcmp(scenario, s))
-	        {
-		  gtk_menu_set_active(GTK_MENU(menu), itemno);
-		}
+			gtk_menu_set_active(GTK_MENU(menu), itemno);
 	  
 	        itemno++;
 	}
 	closedir (dir);
-	g_free (dname);
 }
 
 static void
-cancel (GtkWidget *widget, void *data)
+pref_dialog_response (GtkDialog *dialog, gint response, gpointer data)
 {
-	gtk_widget_destroy (pref_dialog);
-	pref_dialog = 0;
-}
+	if (response == GTK_RESPONSE_OK)
+	{
+		g_free (selected_scenario);
+		selected_scenario = gconf_client_get_string (conf_client, "/apps/same-gnome/tileset", NULL);
+	} else {
+		/* Restore previous scenario */
+		load_scenario (selected_scenario);
 
-static void
-load_scenario_callback (GtkWidget *widget, void *data)
-{
-	if (selected_scenario.scenario) {
-		load_scenario (selected_scenario.scenario);
-		if (selected_scenario.make_it_default) {
-			gnome_config_set_string (
-				"/same-gnome/Preferences/Scenario", 
-				selected_scenario.scenario);
-			gnome_config_sync();
-		}
+		gconf_client_set_string (conf_client, "/apps/same-gnome/tileset", 
+			selected_scenario, NULL);
 	}
-	cancel (0,0);
+
+	gtk_widget_destroy (pref_dialog);
+	pref_dialog = NULL;
 }
 
 static void
 game_preferences_callback (GtkWidget *widget, void *data)
 {
-	GtkWidget *menu, *omenu, *l, *hb, *cb, *f, *fv;
+	GtkWidget *menu, *omenu, *l, *hb, *f;
 	GtkWidget *button;
 
-	if (pref_dialog)
+	if (pref_dialog) {
+		gtk_window_present (GTK_WINDOW (pref_dialog));
 		return;
+	}
 	
-	pref_dialog = gnome_dialog_new (_("Preferences"),
-			GNOME_STOCK_BUTTON_OK, GNOME_STOCK_BUTTON_CANCEL,
+	pref_dialog = gtk_dialog_new_with_buttons (_("Preferences"),
+			GTK_WINDOW (app),
+			GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR
+
+,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
-	gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog), GTK_WINDOW (app));
-	gtk_signal_connect (GTK_OBJECT(pref_dialog), "close",
-			    GTK_SIGNAL_FUNC (cancel), NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog),
+					 GTK_RESPONSE_OK);
+	g_signal_connect (G_OBJECT (pref_dialog), "response",
+			  G_CALLBACK(pref_dialog_response), NULL);
 
 	omenu = gtk_option_menu_new ();
 	menu = gtk_menu_new ();
@@ -589,91 +566,100 @@ game_preferences_callback (GtkWidget *widget, void *data)
 	gtk_widget_show (omenu);
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(omenu), menu);
 
-	f = gtk_frame_new (_ ("Scenario"));
-	gtk_container_border_width (GTK_CONTAINER (f), 5);
+	f = gtk_frame_new (_("Scenario"));
+	gtk_container_set_border_width (GTK_CONTAINER (f), 4);
 
 	hb = gtk_hbox_new (FALSE, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (hb), 4);
 	gtk_widget_show (hb);
 	
 	l = gtk_label_new (_("Select scenario:"));
 	gtk_widget_show (l);
 	    
-	gtk_box_pack_start_defaults (GTK_BOX(hb), l);
+	gtk_box_pack_start (GTK_BOX(hb), l, TRUE, FALSE, 4);
 	gtk_box_pack_start_defaults (GTK_BOX(hb), omenu);
 
-	cb = gtk_check_button_new_with_label ( _("Make it the default scenario") );
-	gtk_signal_connect (GTK_OBJECT(cb), "clicked", (GtkSignalFunc)set_selection_def, NULL);
-	gtk_widget_show (cb);
-
-	fv = gtk_vbox_new (0, 5);
-	gtk_container_border_width (GTK_CONTAINER (fv), 5);
-	gtk_widget_show (fv);
-	
-	gtk_box_pack_start_defaults (GTK_BOX(fv), hb);
-	gtk_box_pack_start_defaults (GTK_BOX(fv), cb);
-	gtk_box_pack_start_defaults (GTK_BOX(GNOME_DIALOG(pref_dialog)->vbox), f);
-	gtk_container_add (GTK_CONTAINER (f), fv);
+	gtk_container_add (GTK_CONTAINER (f), hb);
 	
+	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(pref_dialog)->vbox), f);
 	gtk_widget_show (f);
 	
-	gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 0,
-			GTK_SIGNAL_FUNC (load_scenario_callback), NULL);
-	gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 1,
-			GTK_SIGNAL_FUNC (cancel), (gpointer)1);
-
         gtk_widget_show (pref_dialog);
 }
 
 static int
 game_about_callback (GtkWidget *widget, void *data)
 {
-	GtkWidget *about;
+	GdkPixbuf *pixbuf = NULL;
+	static GtkWidget *about = NULL;
 	const gchar *authors[] = {
 		"Miguel de Icaza.",
 		"Federico Mena.",
-		"Horacio J. Pea.",
+		"Horacio J. Peña.",
 		NULL
 	};
+	gchar *documenters[] = {
+                NULL
+        };
+        /* Translator credits */
+        gchar *translator_credits = _("translator_credits");
 
+	if (about) {
+		gtk_window_present (GTK_WINDOW (about));
+		return;
+	}
+
+	{
+		char *filename = NULL;
+
+		filename = gnome_program_locate_file (NULL,
+				GNOME_FILE_DOMAIN_PIXMAP,  ("gnome-gsame.png"),
+				TRUE, NULL);
+		if (filename != NULL)
+		{
+			pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+			g_free (filename);
+		}
+	}
+	
 	about = gnome_about_new (_("The Same Gnome"), VERSION,
 				 "(C) 1997-1998 the Free Software Foundation",
-				 (const char **)authors,
 				 _("Original idea from KDE's same game program."),
-				 /*"gnome-same-gnome.xpm"*/
-				 NULL);
-	gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(app));
+				 (const char **)authors,
+				 (const char **)documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                                 pixbuf);
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
 	gtk_widget_show (about);
 
-	return TRUE;
-}
+	g_signal_connect (G_OBJECT (about), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &about);
 
-static void
-game_maybe_quit (GtkWidget *widget, int button)
-{
-	if (button == 0) {
-		gtk_widget_destroy (app);
-		gtk_main_quit ();
-	}
+	return TRUE;
 }
 
 static int
 game_quit_callback (GtkWidget *widget, void *data)
 {
-	GtkWidget *box;
-	
-	box = gnome_message_box_new (_("Do you really want to quit?"),
-				     GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_YES,
-				     GNOME_STOCK_BUTTON_NO,
-				     NULL);
-	gnome_dialog_set_parent (GNOME_DIALOG(box), GTK_WINDOW(app));
-	gnome_dialog_set_default (GNOME_DIALOG (box), 0);
-	gtk_window_set_modal (GTK_WINDOW (box), TRUE);
-	gtk_signal_connect (GTK_OBJECT (box), "clicked",
-			   (GtkSignalFunc)game_maybe_quit, NULL);
-	gtk_widget_show (box);
+	if (!game_over) {
+		GtkWidget *box;
+		gint response;
+		
+		box = gtk_message_dialog_new (GTK_WINDOW (app),
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_MESSAGE_QUESTION,
+					     GTK_BUTTONS_YES_NO,
+					     _("Do you really want to quit?"));
 
-	return TRUE;
+		gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_YES);
+		response = gtk_dialog_run (GTK_DIALOG (box));
+		gtk_widget_destroy (box);
+
+		if (response != GTK_RESPONSE_YES)
+			return TRUE;
+	}
+	gtk_main_quit ();
+	return FALSE;
 }
 
 GnomeUIInfo gamemenu[] = {
@@ -686,7 +672,7 @@ GnomeUIInfo gamemenu[] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-        GNOMEUIINFO_MENU_EXIT_ITEM(game_quit_callback, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(game_quit_callback, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -712,9 +698,6 @@ GnomeUIInfo mainmenu[] = {
 	GNOMEUIINFO_END
 };
 
-#define ELEMENTS(x) (sizeof (x) / sizeof (x [0]))
-
-
 static int
 save_state (GnomeClient *client,
 	    gint phase,
@@ -724,34 +707,28 @@ save_state (GnomeClient *client,
 	    gint fast,
 	    gpointer client_data)
 {
-	gchar *prefix = gnome_client_get_config_prefix (client);
 	gchar *argv []= { "rm", "-r", NULL };
 	gchar *buf;
 	struct ball *f = (struct ball*) field;
 	int i;  
 	
-	if (debugging)
-		g_print ("Saving state\n");
-	
-	gnome_config_push_prefix (prefix);
-	
-	gnome_config_set_int ("Game/Score", score);
-	gnome_config_set_int ("Game/NStones", sync_stones ? 1 : nstones);
+	gconf_client_set_int (conf_client, "/apps/same-gnome/score", score, NULL);
+	gconf_client_set_int (conf_client, "/apps/same-gnome/nstones", sync_stones ? 1 : nstones, NULL);
 	
 	buf= g_malloc (STONE_COLS*STONE_LINES+1);
-	
+
 	for (i = 0 ; i < (STONE_COLS*STONE_LINES); i++){
 		buf [i]= f [i].color + 'a';
 	}
 	buf [STONE_COLS*STONE_LINES]= '\0';
-	gnome_config_set_string ("Game/Field", buf);
+	gconf_client_set_string (conf_client, "/apps/same-gnome/field", buf, NULL);
 	g_free(buf);
-	
-	gnome_config_pop_prefix ();
-	gnome_config_sync();
-	
+
+	/* FIXME if anybody knows what this does...
 	argv[2]= gnome_config_get_real_path (prefix);
 	gnome_client_set_discard_command (client, 3, argv);
+	gnome_client_set_discard_command (client, 2, argv);
+	*/
 	
 	return TRUE;
 }
@@ -764,13 +741,10 @@ restart (void)
 	struct ball *f = (struct ball*) field;
 	int i;
 	
-	if (debugging)
-		g_print ("Retrieving state\n");
+	score = gconf_client_get_int (conf_client, "/apps/same-gnome/score", NULL);
+	nstones = gconf_client_get_int (conf_client, "/apps/same-gnome/nstones", NULL);
 	
-	score = gnome_config_get_int_with_default ("Game/Score", 0);
-	nstones = gnome_config_get_int_with_default ("Game/NStones", 0);
-	
-	buf = gnome_config_get_string_with_default ("Game/Field", NULL);  
+	buf = gconf_client_get_string (conf_client, "/apps/same-gnome/field", NULL);
 
 	if (buf) {
 		for (i= 0; i < (STONE_COLS*STONE_LINES); i++) 
@@ -786,17 +760,11 @@ restart (void)
 static gint
 client_die (GnomeClient *client, gpointer client_data)
 {
-        gtk_exit (0);
+        gtk_main_quit ();
 
 	return FALSE;
 }
 
-static const struct poptOption options[] = {
-	{ NULL, 'd', POPT_ARG_NONE, &debugging, 0, N_("Debugging mode"), NULL },
-	{ "scenario", 's', POPT_ARG_STRING, &fname, 0, N_("Set game scenario"), N_("NAME") },
-	{ NULL, '\0', 0, NULL, 0 }
-};
-
 #ifndef GNOME_CLIENT_RESTARTED
 #define GNOME_CLIENT_RESTARTED(client) \
 (GNOME_CLIENT_CONNECTED (client) && \
@@ -808,40 +776,45 @@ static const struct poptOption options[] = {
 int
 main (int argc, char *argv [])
 {
+	static char *fname;
+	static const struct poptOption options[] = {
+		{ "scenario", 's', POPT_ARG_STRING, &fname, 0, N_("Set game scenario"), N_("NAME") },
+		{ NULL, '\0', 0, NULL, 0 }
+	};
 	GtkWidget *label, *separator;
 	GnomeClient *client;
 
 	gnome_score_init("same-gnome");
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 	gnome_init_with_popt_table ("same-gnome", VERSION, argc, argv, options, 0, NULL);
 
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gsame.png");
 	client= gnome_master_client ();
 
-	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
-			    GTK_SIGNAL_FUNC (save_state), argv[0]);
-	gtk_signal_connect (GTK_OBJECT (client), "die",
-			    GTK_SIGNAL_FUNC (client_die), NULL);
+	g_signal_connect (G_OBJECT (client), "save_yourself",
+			  G_CALLBACK (save_state), argv[0]);
+	g_signal_connect (G_OBJECT (client), "die",
+			  G_CALLBACK (client_die), NULL);
 
 	if (GNOME_CLIENT_RESTARTED (client)){
-		gnome_config_push_prefix (gnome_client_get_config_prefix (client));
-	    
 		restart ();
 		restarted = 1;
-		
-		gnome_config_pop_prefix ();
 	}
 
+	/* Get the default GConfClient */
+	conf_client = gconf_client_get_default ();
+
 	srand (time (NULL));
 
 	app = gnome_app_new("same-gnome", _("Same Gnome"));
 
         gtk_window_set_policy(GTK_WINDOW(app), FALSE, FALSE, TRUE);
-	gtk_signal_connect (GTK_OBJECT(app), "delete_event",
-			    (GtkSignalFunc)game_quit_callback, NULL);
+	g_signal_connect (G_OBJECT (app), "delete_event",
+			  G_CALLBACK(game_quit_callback), NULL);
 
 	appbar = gnome_appbar_new(FALSE, TRUE, GNOME_PREFERENCES_USER);
 	gnome_app_set_statusbar(GNOME_APP (app), GTK_WIDGET(appbar));
@@ -857,11 +830,12 @@ main (int argc, char *argv [])
 	gnome_app_set_contents (GNOME_APP (app), vb);
 
 	if (!fname) {
-		fname = gnome_config_get_string
-			("/same-gnome/Preferences/Scenario=stones.png");
+		fname = gconf_client_get_string
+			(conf_client, "/apps/same-gnome/tileset", NULL);
 	}
 
 	create_same_board (fname);
+	selected_scenario = g_strdup (fname);
 
 	separator = gtk_vseparator_new ();
 	label = gtk_label_new (_("Marked: "));
